pub struct GmpClassGroup { /* private fields */ }Implementations
Sourceimpl GmpClassGroup
impl GmpClassGroup
pub fn into_raw(self) -> (Mpz, Mpz)
Sourcepub fn with_context<T, U>(cb: T) -> U
pub fn with_context<T, U>(cb: T) -> U
Call cb with a mutable reference to the context of type Ctx.
The reference cannot escape the closure and cannot be sent across threads.
Panics
Panics if called recursively. This library guarantees that it will
never call this function from any function that takes a parameter of
type &mut Ctx.